aboutsummaryrefslogtreecommitdiff
path: root/libcxx/test/std/language.support/support.limits/support.limits.general/string_view.version.compile.pass.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libcxx/test/std/language.support/support.limits/support.limits.general/string_view.version.compile.pass.cpp')
-rw-r--r--libcxx/test/std/language.support/support.limits/support.limits.general/string_view.version.compile.pass.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/libcxx/test/std/language.support/support.limits/support.limits.general/string_view.version.compile.pass.cpp b/libcxx/test/std/language.support/support.limits/support.limits.general/string_view.version.compile.pass.cpp
index 0a8e2375f06a..8af67d4131be 100644
--- a/libcxx/test/std/language.support/support.limits/support.limits.general/string_view.version.compile.pass.cpp
+++ b/libcxx/test/std/language.support/support.limits/support.limits.general/string_view.version.compile.pass.cpp
@@ -16,7 +16,7 @@
// Test the feature test macros defined by <string_view>
/* Constant Value
- __cpp_lib_char8_t 201811L [C++20]
+ __cpp_lib_char8_t 201907L [C++20]
__cpp_lib_constexpr_string_view 201811L [C++20]
__cpp_lib_starts_ends_with 201711L [C++20]
__cpp_lib_string_contains 202011L [C++2b]
@@ -102,8 +102,8 @@
# ifndef __cpp_lib_char8_t
# error "__cpp_lib_char8_t should be defined in c++20"
# endif
# if __cpp_lib_char8_t != 201811L
# error "__cpp_lib_char8_t should have the value 201811L in c++20"
# endif
# else
# ifdef __cpp_lib_char8_t
@@ -142,8 +142,8 @@
# ifndef __cpp_lib_char8_t
# error "__cpp_lib_char8_t should be defined in c++2b"
# endif
# if __cpp_lib_char8_t != 201811L
# error "__cpp_lib_char8_t should have the value 201811L in c++2b"
# endif
# else
# ifdef __cpp_lib_char8_t
@@ -102,8 +102,8 @@
# error "__cpp_lib_char8_t should be defined in c++20"
# endif
-# if __cpp_lib_char8_t != 201811L
-# error "__cpp_lib_char8_t should have the value 201811L in c++20"
+# if __cpp_lib_char8_t != 201907L
+# error "__cpp_lib_char8_t should have the value 201907L in c++20"
# endif
# else
@@ -142,8 +142,8 @@
# error "__cpp_lib_char8_t should be defined in c++2b"
# endif
-# if __cpp_lib_char8_t != 201811L
-# error "__cpp_lib_char8_t should have the value 201811L in c++2b"
+# if __cpp_lib_char8_t != 201907L
+# error "__cpp_lib_char8_t should have the value 201907L in c++2b"
# endif
# else